==> 2.4.6.tar.gz: android/src/main/kotlin/com/fireworksdk/bridge/models/FWVideoPlayerConfigModelDeserializer.kt <==
package com.fireworksdk.bridge.models

import com.fireworksdk.bridge.models.enums.FWCtaDelayType
import com.fireworksdk.bridge.models.enums.FWPlayerStyle
import com.fireworksdk.bridge.models.enums.FWVideoCompleteAction
import com.fireworksdk.bridge.models.enums.FWVideoPlayerCTAWidth
import org.json.JSONObject

object FWVideoPlayerConfigModelDeserializer {

  private const val PLAYER_STYLE_KEY = "playerStyle"
  private const val VIDEO_COMPLETE_ACTION_KEY = "videoCompleteAction"
  private const val SHOW_SHARE_BUTTON_KEY = "showShareButton"
  private const val CTA_BUTTON_STYLE_KEY = "ctaButtonStyle"
  private const val SHOW_MUTE_BUTTON_KEY = "showMuteButton"
  private const val SHOW_PLAYBACK_BUTTON_KEY = "showPlaybackButton"
  private const val SHOW_BRANDING_KEY = "showBranding"
  private const val CTA_DELAY_KEY = "ctaDelay"
  private const val CTA_HIGHLIGHT_DELAY_KEY = "ctaHighlightDelay"
  private const val SHARE_BASE_URL_KEY = "shareBaseURL"
  private const val CTA_WIDTH_KEY = "ctaWidth"
  private const val ENABLE_PIP_KEY = "enablePictureInPicture"
  private const val SHOW_VIDEO_DETAIL_TITLE_KEY = "showVideoDetailTitle"
  private const val BUTTON_CONFIGURATION_KEY = "buttonConfiguration"

  private const val BACKGROUND_COLOR_KEY = "backgroundColor"
  private const val FONT_SIZE_KEY = "fontSize"
  private const val TEXT_COLOR_KEY = "textColor"

  private const val TYPE_KEY = "type"
  private const val VALUE_KEY = "value"

  fun deserialize(responseJson: JSONObject?): FWVideoPlayerConfigModel? {
    responseJson ?: return null

    val playerStyle = if (responseJson.has(PLAYER_STYLE_KEY)) responseJson.optString(PLAYER_STYLE_KEY) else null
    val videoCompleteAction = if (responseJson.has(VIDEO_COMPLETE_ACTION_KEY)) responseJson.optString(VIDEO_COMPLETE_ACTION_KEY) else null
    val showShareButton = if (responseJson.has(SHOW_SHARE_BUTTON_KEY)) responseJson.optBoolean(SHOW_SHARE_BUTTON_KEY) else null
    val ctaButtonStyle = deserializeCtaButtonStyle(responseJson.optJSONObject(CTA_BUTTON_STYLE_KEY))
    val showMuteButton = if (responseJson.has(SHOW_MUTE_BUTTON_KEY)) responseJson.optBoolean(SHOW_MUTE_BUTTON_KEY) else null
    val showPlaybackButton = if (responseJson.has(SHOW_PLAYBACK_BUTTON_KEY)) responseJson.optBoolean(SHOW_PLAYBACK_BUTTON_KEY) else null
    val showBranding = if (responseJson.has(SHOW_BRANDING_KEY)) responseJson.optBoolean(SHOW_BRANDING_KEY) else null
    val ctaDelay = deserializeCtaDelay(responseJson.optJSONObject(CTA_DELAY_KEY))
    val ctaHighlightDelay = deserializeCtaDelay(responseJson.optJSONObject(CTA_HIGHLIGHT_DELAY_KEY))
    val shareBaseUrl = if (responseJson.has(SHARE_BASE_URL_KEY)) responseJson.optString(SHARE_BASE_URL_KEY) else null
    val ctaWidth = if (responseJson.has(CTA_WIDTH_KEY)) responseJson.optString(CTA_WIDTH_KEY) else null
    val enablePictureInPicture = if (responseJson.has(ENABLE_PIP_KEY)) responseJson.optBoolean(ENABLE_PIP_KEY) else null
    val showVideoDetailTitle = if (responseJson.has(SHOW_VIDEO_DETAIL_TITLE_KEY)) responseJson.optBoolean(SHOW_VIDEO_DETAIL_TITLE_KEY) else null
    val buttonConfigurationJsonObject = responseJson.optJSONObject(BUTTON_CONFIGURATION_KEY)

    return FWVideoPlayerConfigModel(
      playerStyle = if (!playerStyle.isNullOrBlank()) FWPlayerStyle.deserialize(playerStyle) else null,
      videoCompleteAction = if (!videoCompleteAction.isNullOrBlank()) FWVideoCompleteAction.deserialize(videoCompleteAction) else null,
      showShareButton = showShareButton,
      ctaButtonStyle = ctaButtonStyle,
      showMuteButton = showMuteButton,
      showPlaybackButton = showPlaybackButton,
      showBranding = showBranding,
      ctaDelay = ctaDelay,
      ctaHighlightDelay = ctaHighlightDelay,
      shareBaseUrl = shareBaseUrl,
      ctaWidth = if (!ctaWidth.isNullOrBlank()) FWVideoPlayerCTAWidth.deserialize(ctaWidth) else null,
      enablePictureInPicture = enablePictureInPicture,
      showVideoDetailTitle = showVideoDetailTitle,
      buttonConfiguration = FWPlayerButtonConfigurationDeserializer.deserialize(buttonConfigurationJsonObject)
    )
  }

  private fun deserializeCtaButtonStyle(ctaButtonStyleJson: JSONObject?): FWVideoPlayerConfigModel.FWCtaButtonStyleModel {
    ctaButtonStyleJson ?: return FWVideoPlayerConfigModel.FWCtaButtonStyleModel()

    val backgroundColor = if (ctaButtonStyleJson.has(BACKGROUND_COLOR_KEY)) ctaButtonStyleJson.optString(BACKGROUND_COLOR_KEY) else null
    val fontSize = if (ctaButtonStyleJson.has(FONT_SIZE_KEY)) ctaButtonStyleJson.optInt(FONT_SIZE_KEY) else null
    val textColor = if (ctaButtonStyleJson.has(TEXT_COLOR_KEY)) ctaButtonStyleJson.optString(TEXT_COLOR_KEY) else null

    return FWVideoPlayerConfigModel.FWCtaButtonStyleModel(
      backgroundColor = backgroundColor,
      fontSize = fontSize,
      textColor = textColor
    )
  }

  private fun deserializeCtaDelay(ctaDelayJson: JSONObject?): FWVideoPlayerConfigModel.FWCtaDelayModel {
    ctaDelayJson ?: return FWVideoPlayerConfigModel.FWCtaDelayModel()

    val type = if (ctaDelayJson.has(TYPE_KEY)) ctaDelayJson.optString(TYPE_KEY) else null
    val value = if (!ctaDelayJson.isNull(VALUE_KEY)) ctaDelayJson.optDouble(VALUE_KEY) else null

    return FWVideoPlayerConfigModel.FWCtaDelayModel(
      type = if (!type.isNullOrBlank()) FWCtaDelayType.deserialize(type) else null,
      value = value,
    )
  }
}

==> 2.8.0.tar.gz: android/src/main/kotlin/com/fireworksdk/bridge/models/FWVideoPlayerConfigModelDeserializer.kt <==
package com.fireworksdk.bridge.models

import com.fireworksdk.bridge.models.enums.FWCtaDelayType
import com.fireworksdk.bridge.models.enums.FWPlayerStyle
import com.fireworksdk.bridge.models.enums.FWVideoCompleteAction
import com.fireworksdk.bridge.models.enums.FWVideoPlayerCTAWidth
import org.json.JSONObject

object FWVideoPlayerConfigModelDeserializer {

  private const val PLAYER_STYLE_KEY = "playerStyle"
  private const val VIDEO_COMPLETE_ACTION_KEY = "videoCompleteAction"
  private const val SHOW_SHARE_BUTTON_KEY = "showShareButton"
  private const val CTA_BUTTON_STYLE_KEY = "ctaButtonStyle"
  private const val SHOW_MUTE_BUTTON_KEY = "showMuteButton"
  private const val SHOW_PLAYBACK_BUTTON_KEY = "showPlaybackButton"
  private const val SHOW_BRANDING_KEY = "showBranding"
  private const val CTA_DELAY_KEY = "ctaDelay"
  private const val CTA_HIGHLIGHT_DELAY_KEY = "ctaHighlightDelay"
  private const val SHARE_BASE_URL_KEY = "shareBaseURL"
  private const val CTA_WIDTH_KEY = "ctaWidth"
  private const val ENABLE_PIP_KEY = "enablePictureInPicture"
  private const val SHOW_VIDEO_DETAIL_TITLE_KEY = "showVideoDetailTitle"
  private const val BUTTON_CONFIGURATION_KEY = "buttonConfiguration"
  private const val VIDEO_PLAYER_LOGO_CONFIGURATION_KEY = "videoPlayerLogoConfiguration"
  private const val COUNT_DOWN_TIMER_CONFIGURATION_KEY = "countdownTimerConfiguration"

  private const val BACKGROUND_COLOR_KEY = "backgroundColor"
  private const val FONT_SIZE_KEY = "fontSize"
  private const val TEXT_COLOR_KEY = "textColor"

  private const val TYPE_KEY = "type"
  private const val VALUE_KEY = "value"

  fun deserialize(responseJson: JSONObject?): FWVideoPlayerConfigModel? {
    responseJson ?: return null

    val playerStyle = if (responseJson.has(PLAYER_STYLE_KEY)) responseJson.optString(PLAYER_STYLE_KEY) else null
    val videoCompleteAction = if (responseJson.has(VIDEO_COMPLETE_ACTION_KEY)) responseJson.optString(VIDEO_COMPLETE_ACTION_KEY) else null
    val showShareButton = if (responseJson.has(SHOW_SHARE_BUTTON_KEY)) responseJson.optBoolean(SHOW_SHARE_BUTTON_KEY) else null
    val ctaButtonStyle = deserializeCtaButtonStyle(responseJson.optJSONObject(CTA_BUTTON_STYLE_KEY))
    val showMuteButton = if (responseJson.has(SHOW_MUTE_BUTTON_KEY)) responseJson.optBoolean(SHOW_MUTE_BUTTON_KEY) else null
    val showPlaybackButton = if (responseJson.has(SHOW_PLAYBACK_BUTTON_KEY)) responseJson.optBoolean(SHOW_PLAYBACK_BUTTON_KEY) else null
    val showBranding = if (responseJson.has(SHOW_BRANDING_KEY)) responseJson.optBoolean(SHOW_BRANDING_KEY) else null
    val ctaDelay = deserializeCtaDelay(responseJson.optJSONObject(CTA_DELAY_KEY))
    val ctaHighlightDelay = deserializeCtaDelay(responseJson.optJSONObject(CTA_HIGHLIGHT_DELAY_KEY))
    val shareBaseUrl = if (responseJson.has(SHARE_BASE_URL_KEY)) responseJson.optString(SHARE_BASE_URL_KEY) else null
    val ctaWidth = if (responseJson.has(CTA_WIDTH_KEY)) responseJson.optString(CTA_WIDTH_KEY) else null
    val enablePictureInPicture = if (responseJson.has(ENABLE_PIP_KEY)) responseJson.optBoolean(ENABLE_PIP_KEY) else null
    val showVideoDetailTitle = if (responseJson.has(SHOW_VIDEO_DETAIL_TITLE_KEY)) responseJson.optBoolean(SHOW_VIDEO_DETAIL_TITLE_KEY) else null
    val buttonConfigurationJsonObject = responseJson.optJSONObject(BUTTON_CONFIGURATION_KEY)
    val videoPlayerLogoConfigurationJsonObject = responseJson.optJSONObject(VIDEO_PLAYER_LOGO_CONFIGURATION_KEY)
    val countdownTimerConfigurationJsonObject = responseJson.optJSONObject(COUNT_DOWN_TIMER_CONFIGURATION_KEY)

    return FWVideoPlayerConfigModel(
      playerStyle = if (!playerStyle.isNullOrBlank()) FWPlayerStyle.deserialize(playerStyle) else null,
      videoCompleteAction = if (!videoCompleteAction.isNullOrBlank()) FWVideoCompleteAction.deserialize(videoCompleteAction) else null,
      showShareButton = showShareButton,
      ctaButtonStyle = ctaButtonStyle,
      showMuteButton = showMuteButton,
      showPlaybackButton = showPlaybackButton,
      showBranding = showBranding,
      ctaDelay = ctaDelay,
      ctaHighlightDelay = ctaHighlightDelay,
      shareBaseUrl = shareBaseUrl,
      ctaWidth = if (!ctaWidth.isNullOrBlank()) FWVideoPlayerCTAWidth.deserialize(ctaWidth) else null,
      enablePictureInPicture = enablePictureInPicture,
      showVideoDetailTitle = showVideoDetailTitle,
      buttonConfiguration = FWPlayerButtonConfigurationDeserializer.deserialize(buttonConfigurationJsonObject),
      videoPlayerLogoConfiguration = FWVideoPlayerLogoConfigurationModelDeserializer.deserialize(videoPlayerLogoConfigurationJsonObject),
      countdownTimerConfiguration = FWCountdownTimerConfigurationModelDeserializer.deserialize(countdownTimerConfigurationJsonObject),
    )
  }

  private fun deserializeCtaButtonStyle(ctaButtonStyleJson: JSONObject?): FWVideoPlayerConfigModel.FWCtaButtonStyleModel {
    ctaButtonStyleJson ?: return FWVideoPlayerConfigModel.FWCtaButtonStyleModel()

    val backgroundColor = if (ctaButtonStyleJson.has(BACKGROUND_COLOR_KEY)) ctaButtonStyleJson.optString(BACKGROUND_COLOR_KEY) else null
    val fontSize = if (ctaButtonStyleJson.has(FONT_SIZE_KEY)) ctaButtonStyleJson.optInt(FONT_SIZE_KEY) else null
    val textColor = if (ctaButtonStyleJson.has(TEXT_COLOR_KEY)) ctaButtonStyleJson.optString(TEXT_COLOR_KEY) else null

    return FWVideoPlayerConfigModel.FWCtaButtonStyleModel(
      backgroundColor = backgroundColor,
      fontSize = fontSize,
      textColor = textColor
    )
  }

  private fun deserializeCtaDelay(ctaDelayJson: JSONObject?): FWVideoPlayerConfigModel.FWCtaDelayModel {
    ctaDelayJson ?: return FWVideoPlayerConfigModel.FWCtaDelayModel()

    val type = if (ctaDelayJson.has(TYPE_KEY)) ctaDelayJson.optString(TYPE_KEY) else null
    val value = if (!ctaDelayJson.isNull(VALUE_KEY)) ctaDelayJson.optDouble(VALUE_KEY) else null

    return FWVideoPlayerConfigModel.FWCtaDelayModel(
      type = if (!type.isNullOrBlank()) FWCtaDelayType.deserialize(type) else null,
      value = value,
    )
  }
}
